==> rest-sdk-commons-0.1.0-HF1-sources.jar: com/mulesoft/connectivity/rest/commons/api/configuration/RestConfiguration.java <==
/*
 * (c) 2003-2020 MuleSoft, Inc. This software is protected under international copyright
 * law. All use of this software is subject to MuleSoft's Master Subscription Agreement
 * (or other master license agreement) separately entered into in writing between you and
 * MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package com.mulesoft.connectivity.rest.commons.api.configuration;

import static java.util.concurrent.TimeUnit.MINUTES;
import static org.mule.runtime.extension.api.annotation.param.display.Placement.ADVANCED_TAB;

import org.mule.runtime.api.lifecycle.Initialisable;
import org.mule.runtime.extension.api.annotation.param.DefaultEncoding;
import org.mule.runtime.extension.api.annotation.param.Optional;
import org.mule.runtime.extension.api.annotation.param.Parameter;
import org.mule.runtime.extension.api.annotation.param.display.Placement;
import org.mule.runtime.extension.api.annotation.param.display.Summary;

import java.nio.charset.Charset;
import java.util.concurrent.TimeUnit;

/**
 * Base class for configuration objects
 *
 * @since 1.0
 */
public abstract class RestConfiguration implements Initialisable {

  @DefaultEncoding
  private String defaultEncoding;
  private Charset charset;

  /**
   * The timeout for request to the remote service. This value is qualified by
   * the {@link #responseTimeoutUnit}
   */
  @Parameter
  @Optional(defaultValue = "1")
  @Placement(tab = ADVANCED_TAB)
  @Summary("The timeout for request to the remote service.")
  private Integer responseTimeout;

  /**
   * A time unit which qualifies the {@link #responseTimeout}
   */
  @Parameter
  @Optional(defaultValue = "MINUTES")
  @Placement(tab = ADVANCED_TAB)
  @Summary("A time unit which qualifies the Response Timeout}")
  private TimeUnit responseTimeoutUnit = MINUTES;

  /**
   * Defines if the request should be sent using streaming or not.
   * Setting the value to AUTO will automatically define the best strategy based on the request content.
   * As streaming is done the request will be sent user Transfer-Encoding: chunked.
   */
  @Parameter
  @Placement(tab = ADVANCED_TAB)
  @Optional(defaultValue = "AUTO")
  @Summary("Defines if the request should be sent using streaming. "
      + "Setting the value to AUTO will automatically define the best strategy based on the request content.")
  private StreamingType streamingType;

  @Override
  public void initialise() {
    charset = Charset.forName(defaultEncoding);
  }

  public Charset getCharset() {
    return charset;
  }

  public Integer getResponseTimeout() {
    return responseTimeout;
  }

  public TimeUnit getResponseTimeoutUnit() {
    return responseTimeoutUnit;
  }

  public StreamingType getStreamingType() {
    return streamingType;
  }
}

==> rest-sdk-commons-0.7.0-HF1-sources.jar: com/mulesoft/connectivity/rest/commons/api/configuration/RestConfiguration.java <==
/*
 * (c) 2003-2021 MuleSoft, Inc. This software is protected under international copyright
 * law. All use of this software is subject to MuleSoft's Master Subscription Agreement
 * (or other master license agreement) separately entered into in writing between you and
 * MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package com.mulesoft.connectivity.rest.commons.api.configuration;

import static java.util.concurrent.TimeUnit.SECONDS;
import static org.mule.runtime.extension.api.annotation.param.display.Placement.ADVANCED_TAB;

import org.mule.runtime.api.lifecycle.Initialisable;
import org.mule.runtime.extension.api.annotation.param.DefaultEncoding;
import org.mule.runtime.extension.api.annotation.param.Optional;
import org.mule.runtime.extension.api.annotation.param.Parameter;
import org.mule.runtime.extension.api.annotation.param.display.Placement;
import org.mule.runtime.extension.api.annotation.param.display.Summary;

import java.nio.charset.Charset;
import java.util.concurrent.TimeUnit;

/**
 * Base class for configuration objects
 *
 * @since 1.0
 */
public abstract class RestConfiguration implements Initialisable {

  @DefaultEncoding
  private String defaultEncoding;
  private Charset charset;

  /**
   * The timeout for request to the remote service. This value is qualified by the {@link #responseTimeoutUnit}
   */
  @Parameter
  @Optional(defaultValue = "60")
  @Placement(tab = ADVANCED_TAB)
  @Summary("The timeout for request to the remote service.")
  private Integer responseTimeout;

  /**
   * A time unit which qualifies the {@link #responseTimeout}
   */
  @Parameter
  @Optional(defaultValue = "SECONDS")
  @Placement(tab = ADVANCED_TAB)
  @Summary("A time unit which qualifies the Response Timeout}")
  private TimeUnit responseTimeoutUnit = SECONDS;

  /**
   * Defines if the request should be sent using streaming or not. Setting the value to AUTO will automatically define the best
   * strategy based on the request content. As streaming is done the request will be sent user Transfer-Encoding: chunked.
   */
  @Parameter
  @Placement(tab = ADVANCED_TAB)
  @Optional(defaultValue = "AUTO")
  @Summary("Defines if the request should be sent using streaming. "
      + "Setting the value to AUTO will automatically define the best strategy based on the request content.")
  private StreamingType streamingType;

  @Override
  public void initialise() {
    charset = Charset.forName(defaultEncoding);
  }

  public Charset getCharset() {
    return charset;
  }

  public Integer getResponseTimeout() {
    return responseTimeout;
  }

  public TimeUnit getResponseTimeoutUnit() {
    return responseTimeoutUnit;
  }

  public StreamingType getStreamingType() {
    return streamingType;
  }
}
